@@ -251,7 +251,7 @@ def create_rtdh_standard_msg(pd):
             "type": pd.get("data/constructionType", default=""),
             "source": {
                 "id": pd.get("sys_gUid", default=""),
-                "last_updated_timestamp": time.time(),
+                "last_updated_timestamp": date_tools.date_to_unix(datetime.utcnow()),
             },
             "geometry": coordinates,
             "header": {
