@@ -54,7 +54,7 @@ def date_to_unix(time: datetime):
     if not time or type(time) != datetime:
         return None
 
-    return time.timestamp() * 1000
+    return round(time.timestamp() * 1000)
 
 
 # function to get event status from start and end datetimes
